# Generated by Django 3.2.9 on 2021-11-23 13:45

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0028_auto_20210823_2353'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='aou',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='Using META3 approved assessment tool. This response is not criteria for eligibility', max_length=15, null=True, verbose_name="Have the research staff assessed the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='aou_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name="How much time was spent on assessing the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='aou_passed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='This response is not criteria for eligibility', max_length=15, verbose_name='Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='diet_and_lifestyle',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='This response is not criteria for eligibility', max_length=15, null=True, verbose_name='Has the participant received the META3 approved diet and lifetsyle counseling?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='diet_and_lifestyle_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name='How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='fasting_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure')], max_length=15, null=True, verbose_name='In the opinion of the clinican, has the participant fasted?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the META Phase 2 trial?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='real_eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to now', null=True),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='aou',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='Using META3 approved assessment tool. This response is not criteria for eligibility', max_length=15, null=True, verbose_name="Have the research staff assessed the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='aou_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name="How much time was spent on assessing the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='aou_passed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='This response is not criteria for eligibility', max_length=15, verbose_name='Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='diet_and_lifestyle',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='This response is not criteria for eligibility', max_length=15, null=True, verbose_name='Has the participant received the META3 approved diet and lifetsyle counseling?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='diet_and_lifestyle_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name='How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='fasting_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure')], max_length=15, null=True, verbose_name='In the opinion of the clinican, has the participant fasted?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the META Phase 2 trial?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='real_eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to now', null=True),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='aou',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='Using META3 approved assessment tool. This response is not criteria for eligibility', max_length=15, null=True, verbose_name="Have the research staff assessed the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='aou_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name="How much time was spent on assessing the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='aou_passed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='This response is not criteria for eligibility', max_length=15, verbose_name='Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='diet_and_lifestyle',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='This response is not criteria for eligibility', max_length=15, null=True, verbose_name='Has the participant received the META3 approved diet and lifetsyle counseling?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='diet_and_lifestyle_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name='How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='fasting_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure')], max_length=15, null=True, verbose_name='In the opinion of the clinican, has the participant fasted?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the META Phase 2 trial?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='real_eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to now', null=True),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='aou',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='Using META3 approved assessment tool. This response is not criteria for eligibility', max_length=15, null=True, verbose_name="Have the research staff assessed the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='aou_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name="How much time was spent on assessing the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='aou_passed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='This response is not criteria for eligibility', max_length=15, verbose_name='Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='diet_and_lifestyle',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='This response is not criteria for eligibility', max_length=15, null=True, verbose_name='Has the participant received the META3 approved diet and lifetsyle counseling?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='diet_and_lifestyle_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name='How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='fasting_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure')], max_length=15, null=True, verbose_name='In the opinion of the clinican, has the participant fasted?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the META Phase 2 trial?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='real_eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to now', null=True),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='aou',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='Using META3 approved assessment tool. This response is not criteria for eligibility', max_length=15, null=True, verbose_name="Have the research staff assessed the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='aou_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name="How much time was spent on assessing the subject's understanding of the study?"),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='aou_passed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='This response is not criteria for eligibility', max_length=15, verbose_name='Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='diet_and_lifestyle',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='This response is not criteria for eligibility', max_length=15, null=True, verbose_name='Has the participant received the META3 approved diet and lifetsyle counseling?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='diet_and_lifestyle_duration',
            field=models.IntegerField(help_text='Report in minutes. This response is not criteria for eligibility', null=True, verbose_name='How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='fasting_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure')], max_length=15, null=True, verbose_name='In the opinion of the clinican, has the participant fasted?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the META Phase 2 trial?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='real_eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to now', null=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to report_datetime', null=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='As reported by patient', max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='fasting_duration_str',
            field=models.CharField(blank=True, help_text='As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc', max_length=8, null=True, validators=[django.core.validators.RegexValidator('^([0-9]{1,3}h([0-5]?[0-9]m)?)$', message='Invalid format. Expected something like 1h20m, 11h5m, etc')], verbose_name='How long have they fasted in hours and/or minutes?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to report_datetime', null=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='As reported by patient', max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='fasting_duration_str',
            field=models.CharField(blank=True, help_text='As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc', max_length=8, null=True, validators=[django.core.validators.RegexValidator('^([0-9]{1,3}h([0-5]?[0-9]m)?)$', message='Invalid format. Expected something like 1h20m, 11h5m, etc')], verbose_name='How long have they fasted in hours and/or minutes?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to report_datetime', null=True),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='As reported by patient', max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='fasting_duration_str',
            field=models.CharField(blank=True, help_text='As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc', max_length=8, null=True, validators=[django.core.validators.RegexValidator('^([0-9]{1,3}h([0-5]?[0-9]m)?)$', message='Invalid format. Expected something like 1h20m, 11h5m, etc')], verbose_name='How long have they fasted in hours and/or minutes?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to report_datetime', null=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='As reported by patient', max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='fasting_duration_str',
            field=models.CharField(blank=True, help_text='As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc', max_length=8, null=True, validators=[django.core.validators.RegexValidator('^([0-9]{1,3}h([0-5]?[0-9]m)?)$', message='Invalid format. Expected something like 1h20m, 11h5m, etc')], verbose_name='How long have they fasted in hours and/or minutes?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='eligibility_datetime',
            field=models.DateTimeField(editable=False, help_text='Date and time eligibility was determined relative to report_datetime', null=True),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='As reported by patient', max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='fasting_duration_str',
            field=models.CharField(blank=True, help_text='As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc', max_length=8, null=True, validators=[django.core.validators.RegexValidator('^([0-9]{1,3}h([0-5]?[0-9]m)?)$', message='Invalid format. Expected something like 1h20m, 11h5m, etc')], verbose_name='How long have they fasted in hours and/or minutes?'),
        ),
    ]



# Generated by Django 3.2.11 on 2022-03-09 18:06

import _socket
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.validators.date
import edc_utils.date
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('edc_action_item', '0028_auto_20210203_0706'),
        ('sites', '0002_alter_domain_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('meta_prn', '0017_auto_20220307_1929'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='delivery',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'), 'get_latest_by': 'modified', 'ordering': ('-modified', '-created'), 'verbose_name': 'Delivery', 'verbose_name_plural': 'Delivery'},
        ),
        migrations.AlterModelOptions(
            name='historicaldelivery',
            options={'get_latest_by': 'history_date', 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Delivery'},
        ),
        migrations.AlterField(
            model_name='delivery',
            name='maternal_outcome',
            field=models.CharField(choices=[('no_complications', 'No complications'), ('complications_full_recovery', 'Complications with full recovery'), ('complications_ongoing_recovery', 'Complications with ongoing recovery'), ('dead', 'Maternal mortality')], max_length=50, verbose_name='What was the maternal outcome of the pregnancy?'),
        ),
        migrations.AlterField(
            model_name='historicaldelivery',
            name='maternal_outcome',
            field=models.CharField(choices=[('no_complications', 'No complications'), ('complications_full_recovery', 'Complications with full recovery'), ('complications_ongoing_recovery', 'Complications with ongoing recovery'), ('dead', 'Maternal mortality')], max_length=50, verbose_name='What was the maternal outcome of the pregnancy?'),
        ),
        migrations.AlterUniqueTogether(
            name='delivery',
            unique_together={('subject_identifier', 'delivery_datetime')},
        ),
        migrations.CreateModel(
            name='HistoricalPregnancyNotification',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('subject_identifier', models.CharField(max_length=50)),
                ('tracking_identifier', models.CharField(db_index=True, max_length=32)),
                ('action_identifier', models.CharField(db_index=True, max_length=50)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, verbose_name='Report Date and Time')),
                ('bhcg_confirmed', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=5, verbose_name='Has the pregnancy been confirmed by urine βHCG?')),
                ('unconfirmed_details', models.TextField(blank=True, null=True, verbose_name='If no, please provide details')),
                ('edd', models.DateField(validators=[edc_model.models.validators.date.date_is_future], verbose_name='Estimated date of delivery :')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('parent_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
            ],
            options={
                'verbose_name': 'historical Pregnancy Notification',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalBirthOutcomes',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('tracking_identifier', models.CharField(db_index=True, max_length=32)),
                ('action_identifier', models.CharField(db_index=True, max_length=50)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('maternal_identifier', models.CharField(max_length=50)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, verbose_name='Report Date and Time')),
                ('birth_order', models.IntegerField()),
                ('birth_outcome', models.CharField(choices=[('live_at_term', 'Live birth at term'), ('live_preterm', 'Live birth preterm'), ('stillbirth', 'Stillbirth'), ('miscarriage', 'Miscarriage')], max_length=25, verbose_name='Outcome')),
                ('birth_weight', models.IntegerField(blank=True, help_text='gm', null=True, verbose_name='Weight (gm)')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('delivery', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='meta_prn.delivery')),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('parent_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
            ],
            options={
                'verbose_name': 'historical Birth Outcomes',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='PregnancyNotification',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('subject_identifier', models.CharField(max_length=50)),
                ('tracking_identifier', models.CharField(max_length=32, unique=True)),
                ('action_identifier', models.CharField(max_length=50, unique=True)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, verbose_name='Report Date and Time')),
                ('bhcg_confirmed', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=5, verbose_name='Has the pregnancy been confirmed by urine βHCG?')),
                ('unconfirmed_details', models.TextField(blank=True, null=True, verbose_name='If no, please provide details')),
                ('edd', models.DateField(validators=[edc_model.models.validators.date.date_is_future], verbose_name='Estimated date of delivery :')),
                ('action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem')),
                ('parent_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
            ],
            options={
                'verbose_name': 'Pregnancy Notification',
                'verbose_name_plural': 'Pregnancy Notifications',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
                'unique_together': {('subject_identifier', 'edd')},
            },
        ),
        migrations.CreateModel(
            name='BirthOutcomes',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('tracking_identifier', models.CharField(max_length=32, unique=True)),
                ('action_identifier', models.CharField(max_length=50, unique=True)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('maternal_identifier', models.CharField(max_length=50)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, verbose_name='Report Date and Time')),
                ('birth_order', models.IntegerField()),
                ('birth_outcome', models.CharField(choices=[('live_at_term', 'Live birth at term'), ('live_preterm', 'Live birth preterm'), ('stillbirth', 'Stillbirth'), ('miscarriage', 'Miscarriage')], max_length=25, verbose_name='Outcome')),
                ('birth_weight', models.IntegerField(blank=True, help_text='gm', null=True, verbose_name='Weight (gm)')),
                ('action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem')),
                ('delivery', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='meta_prn.delivery')),
                ('parent_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
            ],
            options={
                'verbose_name': 'Birth Outcomes',
                'verbose_name_plural': 'Birth Outcomes',
                'ordering': ['maternal_identifier', 'birth_order'],
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
                'unique_together': {('maternal_identifier', 'birth_order')},
            },
        ),
    ]



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_form_validators import FormValidator

from ..models import ComplicationsGlycemia


class AdditionalScreeningFormValidator(FormValidator):
    def clean(self):
        pass


class ComplicationsGlycemiaForm(CrfModelFormMixin, forms.ModelForm):

    form_validator_cls = AdditionalScreeningFormValidator

    class Meta:
        model = ComplicationsGlycemia
        fields = "__all__"



# Generated by Django 2.2.7 on 2020-01-18 15:54

import edc_vitals.models.fields.blood_pressure
import edc_vitals.models.fields.height
import edc_vitals.models.fields.weight
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0017_auto_20191213_0314"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="height",
            field=edc_vitals.models.fields.height.HeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="height",
            field=edc_vitals.models.fields.height.HeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="height",
            field=edc_vitals.models.fields.height.HeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="height",
            field=edc_vitals.models.fields.height.HeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="height",
            field=edc_vitals.models.fields.height.HeightField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
        ),
    ]



from django.db import models
from edc_constants.choices import PRESENT_ABSENT_NA, YES_NO
from edc_constants.constants import NOT_APPLICABLE
from edc_model import models as edc_models

from ..choices import MALARIA_TEST_CHOICES
from ..model_mixins import CrfModelMixin


class MalariaTest(CrfModelMixin, edc_models.BaseUuidModel):

    performed = models.CharField(
        verbose_name="Was the malaria test performed?",
        max_length=15,
        choices=YES_NO,
    )

    not_performed_reason = models.CharField(
        verbose_name="If NO, provide reason", max_length=150, null=True, blank=True
    )

    diagnostic_type = models.CharField(
        verbose_name="Diagnostic test used",
        max_length=15,
        choices=MALARIA_TEST_CHOICES,
        default=NOT_APPLICABLE,
    )

    result = models.CharField(
        verbose_name="Result",
        max_length=25,
        choices=PRESENT_ABSENT_NA,
        default=NOT_APPLICABLE,
    )

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Malaria Test"



from edc_constants.constants import DEAD, NOT_APPLICABLE, OTHER, UNKNOWN

list_data = {
    "edc_adverse_event.aeclassification": [
        ("lactic_acidosis", "Lactic acidosis"),
        ("hepatomegaly_steatosis", "Hepatomegaly with steatosis"),
        ("gastrointestinal_metformin", "Gastrointestinal effects of metformin"),
        # ("anaemia", "Anaemia"),
        # ("diarrhoea", "Diarrhoea"),
        # ("renal_impairment", "Renal impairment"),
        (OTHER, "Other"),
    ],
    "edc_adverse_event.saereason": [
        (NOT_APPLICABLE, "Not applicable"),
        (DEAD, "Death"),
        ("life_threatening", "Life-threatening"),
        ("significant_disability", "Significant disability"),
        (
            "in-patient_hospitalization",
            (
                "In-patient hospitalization or prolongation "
                "(17 or more days from study inclusion)"
            ),
        ),
        (
            "medically_important_event",
            "Medically important event (e.g. Severe thrombophlebitis, Bacteraemia, "
            "recurrence of symptoms not requiring admission, Hospital acquired "
            "pneumonia)",
        ),
    ],
    "edc_adverse_event.causeofdeath": [
        ("art_toxicity", "ART toxicity"),
        ("diarrhea_wasting", "Diarrhea/wasting"),
        (UNKNOWN, "Unknown"),
        (OTHER, "Other"),
    ],
}



from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_constants.constants import FEMALE, YES
from edc_lab_panel.panels import hba1c_panel
from edc_metadata.metadata_rules import PredicateCollection
from edc_registration.models import RegisteredSubject
from edc_visit_schedule.constants import DAY1, MONTH1, MONTH3, MONTH6, WEEK2
from edc_visit_schedule.utils import is_baseline

from meta_visit_schedule.constants import SCHEDULE_PREGNANCY


def hba1c_crf_required_at_baseline(visit):
    model_name = "meta_subject.bloodresultshba1c"
    screening_model_cls = django_apps.get_model("meta_screening.subjectscreening")
    bloodresults_model_cls = django_apps.get_model(model_name)
    required = False
    if is_baseline(visit):
        try:
            screening_model_cls.objects.get(
                subject_identifier=visit.subject_identifier,
                hba1c_value__isnull=True,
            )
        except ObjectDoesNotExist:
            pass
        else:
            try:
                obj = bloodresults_model_cls.objects.get(
                    subject_visit__visit_code=DAY1,
                    subject_visit__visit_code_sequence=0,
                )
            except ObjectDoesNotExist:
                required = True
            else:
                if not obj.hba1c_value:
                    required = True
    return required


def hba1c_requisition_required_at_baseline(visit):
    screening_model_cls = django_apps.get_model("meta_screening.subjectscreening")
    required = False
    if is_baseline(visit):
        try:
            screening_model_cls.objects.get(
                subject_identifier=visit.subject_identifier,
                hba1c_value__isnull=False,
            )
        except ObjectDoesNotExist:
            required = True
    return required


class Predicates(PredicateCollection):

    app_label = "meta_subject"
    visit_model = "meta_subject.subjectvisit"

    @staticmethod
    def pregnancy_notification_exists(visit, **kwargs):
        model_cls = django_apps.get_model("meta_prn.pregnancynotification")
        try:
            model_cls.objects.get(
                subject_identifier=visit.subject_identifier, delivered=False
            )
        except ObjectDoesNotExist:
            required = False
        else:
            required = True
        return required

    @staticmethod
    def hba1c_crf_required(visit, **kwargs) -> bool:
        """Require at baseline visit if not recorded on the
        screening form.
        """
        required = hba1c_crf_required_at_baseline(visit)
        if (
            not required
            and visit.appointment.visit_code != DAY1
            and visit.appointment.visit_code_sequence == 0
            and visit.appointment.visit_code
            in visit.schedule.crf_required_at("meta_subject.bloodresultshba1c")
        ):
            required = True
        return required

    @staticmethod
    def hba1c_requisition_required(visit, **kwargs) -> bool:
        """Require at baseline visit if not recorded on the
        screening form.
        """
        required = hba1c_requisition_required_at_baseline(visit)
        if (
            not required
            and visit.appointment.visit_code != DAY1
            and visit.appointment.visit_code_sequence == 0
            and visit.appointment.visit_code
            in visit.schedule.requisition_required_at(hba1c_panel)
        ):
            required = True
        return required

    def health_economics_required(self, visit, **kwargs) -> bool:
        """Returns true if HE was not completed at week 2"""

        required = False
        if (
            visit.appointment.visit_code == WEEK2
            and visit.appointment.visit_code_sequence == 0
        ):
            required = True
        elif (
            visit.appointment.visit_code == MONTH1
            and visit.appointment.visit_code_sequence == 0
        ):

            model_cls = django_apps.get_model(f"{self.app_label}.healtheconomicssimple")
            try:
                model_cls.objects.get(
                    subject_visit__subject_identifier=visit.subject_identifier,
                    subject_visit__visit_code=WEEK2,
                    subject_visit__visit_code_sequence=0,
                )
            except ObjectDoesNotExist:
                required = True
        return required

    @staticmethod
    def urine_pregnancy_required(visit, **kwargs) -> bool:
        """Returns True if required.

        Bu default is not required at baseline, otherwise at 1, 3, 6, etc"""
        registered_subject = RegisteredSubject.objects.get(
            subject_identifier=visit.subject_identifier
        )
        if (
            registered_subject.gender == FEMALE
            and visit.schedule_name != SCHEDULE_PREGNANCY
            and not is_baseline(visit)
            and not (
                visit.appointment.visit_code == WEEK2
                and visit.appointment.visit_code_sequence == 0
            )
        ):
            return True
        else:
            return False

    def mnsi_required(self, visit, **kwargs) -> bool:
        """Returns True if MNSI assessment was not performed at the
        1M, 3M or 6M visits.
        """
        required = True
        if (
            visit.appointment.visit_code in [MONTH1, MONTH3, MONTH6]
        ) and visit.appointment.visit_code_sequence == 0:
            model_cls = django_apps.get_model(f"{self.app_label}.mnsi")
            objs = model_cls.objects.filter(
                subject_visit__subject_identifier=visit.subject_identifier,
                subject_visit__visit_code__in=[MONTH1, MONTH3, MONTH6],
                subject_visit__visit_code_sequence=0,
            )
            for obj in objs:
                if obj.mnsi_performed == YES:
                    required = False
                    break
        return required



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_screening_admin
from ..forms import (
    ScreeningPartThreeForm,
    calculated_fields,
    get_part_one_fields,
    get_part_two_fields,
)
from ..models import ScreeningPartThree
from .fieldsets import (
    calculated_values_fieldset,
    comments_fieldset,
    get_part_one_fieldset,
    get_part_three_creatinine_fieldset,
    get_part_three_glucose_fieldset,
    get_part_three_hba1c_fieldset,
    get_part_three_pregnancy_fieldset,
    get_part_three_repeat_glucose_fieldset,
    get_part_three_report_datetime_fieldset,
    get_part_three_vitals_fieldset,
    get_part_two_fieldset,
)
from .subject_screening_admin import SubjectScreeningAdmin


def get_fieldsets():
    return (
        get_part_one_fieldset(collapse=True),
        get_part_two_fieldset(collapse=True),
        get_part_three_report_datetime_fieldset(),
        get_part_three_vitals_fieldset(),
        get_part_three_pregnancy_fieldset(),
        get_part_three_glucose_fieldset(),
        get_part_three_repeat_glucose_fieldset(),
        get_part_three_creatinine_fieldset(),
        get_part_three_hba1c_fieldset(),
        comments_fieldset,
        calculated_values_fieldset,
        audit_fieldset_tuple,
    )


@admin.register(ScreeningPartThree, site=meta_screening_admin)
class ScreeningPartThreeAdmin(SubjectScreeningAdmin):

    form = ScreeningPartThreeForm

    fieldsets = get_fieldsets()

    readonly_fields = (
        *get_part_one_fields(),
        *get_part_two_fields(),
        *calculated_fields,
    )



from django import forms
from edc_constants.constants import NO, YES
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_form_validators import FormValidator

from ..models import PregnancyUpdate


class PregnancyUpdateFormValidator(FormValidator):
    def clean(self):
        self.required_if(YES, field="contact", field_required="comment")


class PregnancyUpdateForm(CrfModelFormMixin, forms.ModelForm):

    form_validator_cls = PregnancyUpdateFormValidator

    class Meta:
        model = PregnancyUpdate
        fields = "__all__"



from django.contrib.auth.models import User
from django.test import TestCase, tag
from django.test.client import RequestFactory
from edc_adverse_event.models import AeClassification
from model_bakery import baker

from meta_reports.ae_report import AeReport
from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin


class TestReports(MetaTestCaseMixin, TestCase):
    def setUp(self):
        self.user = User.objects.create(
            username="erikvw", is_staff=True, is_active=True
        )
        subject_screening = self.get_subject_screening()
        subject_consent = self.get_subject_consent(subject_screening)
        self.subject_identifier = subject_consent.subject_identifier

    def test_aereport(self):

        rf = RequestFactory()
        request = rf.get("/")
        request.user = self.user
        ae_classification = AeClassification.objects.all()[0]
        ae_initial = baker.make_recipe(
            "meta_ae.aeinitial",
            subject_identifier=self.subject_identifier,
            ae_classification=ae_classification,
        )

        report = AeReport(
            ae_initial=ae_initial,
            subject_identifier=ae_initial.subject_identifier,
            user=request.user,
            request=request,
        )
        return report.render()



from edc_blood_results import BLOOD_RESULTS_LFT_ACTION
from edc_blood_results.model_mixins import (
    AlbuminModelMixin,
    AlpModelMixin,
    AltModelMixin,
    AmylaseModelMixin,
    AstModelMixin,
    BloodResultsModelMixin,
    GgtModelMixin,
)
from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
from edc_lab.model_mixins import CrfWithRequisitionModelMixin
from edc_lab_panel.panels import lft_panel
from edc_model import models as edc_models


class BloodResultsLft(
    CrfWithActionModelMixin,
    AlbuminModelMixin,
    AlpModelMixin,
    AltModelMixin,
    AmylaseModelMixin,
    AstModelMixin,
    GgtModelMixin,
    CrfWithRequisitionModelMixin,
    BloodResultsModelMixin,
    edc_models.BaseUuidModel,
):
    action_name = BLOOD_RESULTS_LFT_ACTION
    tracking_identifier_prefix = "LF"
    lab_panel = lft_panel

    class Meta(CrfWithActionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Blood Result: LFT"
        verbose_name_plural = "Blood Results: LFT"



from django.contrib import admin
from edc_data_manager.data_manager_modeladmin_mixin import DataManagerModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin

from ..admin_site import meta_prn_admin
from ..models import OffSchedule


@admin.register(OffSchedule, site=meta_prn_admin)
class OffScheduleAdmin(
    DataManagerModelAdminMixin, ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin
):

    instructions = None
    fields = ("subject_identifier", "offschedule_datetime")

    list_display = ("subject_identifier", "dashboard", "offschedule_datetime")

    list_filter = ("offschedule_datetime",)

    def get_readonly_fields(self, request, obj=None):
        return ["subject_identifier", "offschedule_datetime"]



# Generated by Django 3.2.11 on 2022-04-03 09:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0040_auto_20220316_2147'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='Yes', max_length=15, verbose_name='Does the patient have a viral load measure of < 400 copies/ml taken within the last 6 months'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='Yes', max_length=15, verbose_name='Does the patient have a viral load measure of < 400 copies/ml taken within the last 6 months'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='Yes', max_length=15, verbose_name='Does the patient have a viral load measure of < 400 copies/ml taken within the last 6 months'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='Yes', max_length=15, verbose_name='Does the patient have a viral load measure of < 400 copies/ml taken within the last 6 months'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='Yes', max_length=15, verbose_name='Does the patient have a viral load measure of < 400 copies/ml taken within the last 6 months'),
            preserve_default=False,
        ),
    ]



from django.contrib import admin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import meta_ae_admin
from ..forms import AeSponsorReviewForm
from ..models import AeSponsorReview
from .modeladmin_mixins import AeReviewModelAdminMixin


@admin.register(AeSponsorReview, site=meta_ae_admin)
class AeSponsorReviewAdmin(AeReviewModelAdminMixin, SimpleHistoryAdmin):

    form = AeSponsorReviewForm



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_subject_admin
from ..forms import MalariaTestForm
from ..models import MalariaTest
from .modeladmin import CrfModelAdmin


@admin.register(MalariaTest, site=meta_subject_admin)
class MalariaTestAdmin(CrfModelAdmin):

    form = MalariaTestForm

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "subject_visit",
                    "report_datetime",
                    "performed",
                    "diagnostic_type",
                    "not_performed_reason",
                    "result",
                )
            },
        ),
        audit_fieldset_tuple,
    )

    radio_fields = {
        "performed": admin.VERTICAL,
        "diagnostic_type": admin.VERTICAL,
        "result": admin.VERTICAL,
    }



# Generated by Django 3.2.4 on 2021-08-09 14:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0074_auto_20210809_1744"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="on_hypertension_treatment",
            new_name="on_htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="on_hypertension_treatment",
            new_name="on_htn_treatment",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="diabetes_in_family",
            new_name="dm_in_family",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="other_diabetes_symptoms",
            new_name="other_dm_symptoms",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="other_hypertension_treatment",
            new_name="other_htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="diabetes_in_family",
            new_name="dm_in_family",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="diabetes_symptoms",
            new_name="dm_symptoms",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="hypertension_treatment",
            new_name="htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="other_diabetes_symptoms",
            new_name="other_dm_symptoms",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="other_hypertension_treatment",
            new_name="other_htn_treatment",
        ),
    ]



from django.contrib import admin
from edc_blood_results.admin import BloodResultsModelAdminMixin
from edc_blood_results.fieldsets import BloodResultFieldset

from ...admin_site import meta_subject_admin
from ...forms import BloodResultsLipidForm
from ...models import BloodResultsLipid
from ..modeladmin import CrfModelAdmin


@admin.register(BloodResultsLipid, site=meta_subject_admin)
class BloodResultsLipidAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
    form = BloodResultsLipidForm
    fieldsets = BloodResultFieldset(
        BloodResultsLipid.lab_panel, model_cls=BloodResultsLipid
    ).fieldsets



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_qol.admin import eq5d3l_fieldsets, eq5d3l_radio_fields

from ..admin_site import meta_subject_admin
from ..forms import Eq5d3lForm
from ..models import Eq5d3l
from .modeladmin import CrfModelAdmin


@admin.register(Eq5d3l, site=meta_subject_admin)
class Eq5d3lAdmin(CrfModelAdmin):

    form = Eq5d3lForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        *eq5d3l_fieldsets(),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    radio_fields = eq5d3l_radio_fields()



# Generated by Django 3.2.6 on 2021-09-10 16:11
from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from django.db.migrations import RunPython


def convert_actions_required_to_fk(apps, schema_editor):
    model_cls = apps.get_model("meta_prn", "protocoldeviationviolation")
    list_model_cls = apps.get_model("edc_protocol_violation", "actionsrequired")
    for obj in model_cls.objects.all():
        try:
            action_required = list_model_cls.objects.get(name=obj.action_required_old)
        except ObjectDoesNotExist as e:
            raise ObjectDoesNotExist(f"{e}. Got name={obj.action_required_old}")

        obj.action_required = action_required
        obj.save()


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0010_auto_20210910_1906"),
    ]

    operations = [RunPython(convert_actions_required_to_fk)]



from edc_action_item.auth_objects import (
    ACTION_ITEM,
    ACTION_ITEM_EXPORT,
    ACTION_ITEM_VIEW_ONLY,
)
from edc_adverse_event.auth_objects import (
    AE,
    AE_REVIEW,
    AE_SUPER,
    TMG,
    TMG_REVIEW,
    TMG_ROLE,
)
from edc_appointment.auth_objects import (
    APPOINTMENT,
    APPOINTMENT_EXPORT,
    APPOINTMENT_VIEW,
)
from edc_auth.auth_objects import (
    AUDITOR,
    AUDITOR_ROLE,
    CLINIC,
    CLINICIAN_ROLE,
    CLINICIAN_SUPER_ROLE,
    NURSE_ROLE,
)
from edc_auth.site_auths import site_auths
from edc_data_manager.auth_objects import (
    DATA_MANAGER_EXPORT,
    DATA_MANAGER_ROLE,
    SITE_DATA_MANAGER_ROLE,
)
from edc_export.auth_objects import DATA_EXPORTER_ROLE
from edc_label.auth_objects import LABELING
from edc_mnsi.auth_objects import MNSI, MNSI_SUPER, MNSI_VIEW
from edc_offstudy.auth_objects import OFFSTUDY
from edc_pharmacy.auth_objects import PHARMACIST_ROLE, SITE_PHARMACIST_ROLE
from edc_qol.auth_objects import QOL, QOL_SUPER, QOL_VIEW
from edc_randomization.auth_objects import RANDO_BLINDED, RANDO_UNBLINDED
from edc_screening.auth_objects import SCREENING, SCREENING_VIEW
from edc_unblinding.auth_objects import UNBLINDING_REQUESTORS
from sarscov2.auth import SARSCOV2, sarscov2_codenames

from .auth_objects import META_AUDITOR, META_CLINIC, META_CLINIC_SUPER, clinic_codenames

# meta groups
site_auths.add_group(*clinic_codenames, name=META_AUDITOR, view_only=True)
site_auths.add_group(*clinic_codenames, name=META_CLINIC, no_delete=True)
site_auths.add_group(*clinic_codenames, name=META_CLINIC_SUPER)

# update edc roles
site_auths.update_role(
    ACTION_ITEM,
    AE,
    APPOINTMENT,
    META_CLINIC,
    UNBLINDING_REQUESTORS,
    MNSI,
    QOL,
    name=CLINICIAN_ROLE,
)

site_auths.update_role(
    ACTION_ITEM,
    AE_SUPER,
    APPOINTMENT,
    META_CLINIC_SUPER,
    MNSI_SUPER,
    QOL_SUPER,
    UNBLINDING_REQUESTORS,
    name=CLINICIAN_SUPER_ROLE,
)

site_auths.update_role(
    ACTION_ITEM,
    AE,
    APPOINTMENT,
    META_CLINIC,
    MNSI,
    QOL,
    name=NURSE_ROLE,
)

site_auths.update_role(
    ACTION_ITEM,
    AE,
    APPOINTMENT,
    CLINIC,
    LABELING,
    META_CLINIC,
    MNSI,
    QOL,
    OFFSTUDY,
    SCREENING,
    TMG,
    name=DATA_MANAGER_ROLE,
)

site_auths.update_role(ACTION_ITEM, UNBLINDING_REQUESTORS, name=TMG_ROLE)

site_auths.update_role(
    ACTION_ITEM_VIEW_ONLY,
    AE_REVIEW,
    APPOINTMENT_VIEW,
    META_AUDITOR,
    MNSI_VIEW,
    QOL_VIEW,
    TMG_REVIEW,
    name=AUDITOR_ROLE,
)

site_auths.update_role(
    AUDITOR,
    ACTION_ITEM,
    AE_REVIEW,
    META_AUDITOR,
    MNSI_VIEW,
    QOL_VIEW,
    SCREENING_VIEW,
    TMG_REVIEW,
    name=SITE_DATA_MANAGER_ROLE,
)


# data export
site_auths.update_role(
    ACTION_ITEM_EXPORT,
    APPOINTMENT_EXPORT,
    DATA_MANAGER_EXPORT,
    name=DATA_EXPORTER_ROLE,
)

site_auths.update_role(RANDO_UNBLINDED, name=PHARMACIST_ROLE)
site_auths.update_role(RANDO_BLINDED, name=SITE_PHARMACIST_ROLE)



from django.contrib import admin
from edc_adherence.model_admin_mixin import MedicationAdherenceAdminMixin

from ..admin_site import meta_subject_admin
from ..forms import MedicationAdherenceForm
from ..models import MedicationAdherence
from .modeladmin import CrfModelAdmin


@admin.register(MedicationAdherence, site=meta_subject_admin)
class MedicationAdherenceAdmin(MedicationAdherenceAdminMixin, CrfModelAdmin):

    form = MedicationAdherenceForm

    radio_fields = {
        "pill_count_performed": admin.VERTICAL,
        "last_missed_pill": admin.VERTICAL,
    }



# Generated by Django 2.2.11 on 2020-03-25 06:01

import django.core.validators
import edc_visit_tracking.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0016_auto_20200123_1508"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="bloodresultsfbc",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultshba1c",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslft",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslipid",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsrft",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
    ]



from django.db import models

# TODO: add assessment of understanding section (P4?) and duration?
#  (WAIT, just ask if the assessment form was completed)
# TODO: diet and lifestyle discussion duration?
#  (WAIT, skip for now. Training issue, not to be documented)
from edc_constants.choices import YES_NO, YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE


class PartFourFieldsModelMixin(models.Model):

    # added 19/11/2021
    # TODO: "In the opinion of the clinican, has the participant fasted?"
    # TODO: the second measure is used for eligibility

    # Assessment of understanding
    aou = models.CharField(
        verbose_name=(
            "Have the research staff assessed the "
            "subject's understanding of the study?"
        ),
        max_length=15,
        choices=YES_NO,
        null=True,
        blank=False,
        help_text=(
            "Using META3 approved assessment tool. "
            "This response is not criteria for eligibility"
        ),
    )

    aou_duration = models.IntegerField(
        verbose_name=(
            "How much time was spent on assessing "
            "the subject's understanding of the study?"
        ),
        null=True,
        blank=False,
        help_text="Report in minutes. This response is not criteria for eligibility",
    )

    aou_passed = models.CharField(
        verbose_name=(
            "Based on the META3 approved assessment tool, has the subject "
            "demonstrated sufficient understanding of the study to continue?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        blank=False,
        help_text="This response is not criteria for eligibility",
    )

    class Meta:
        abstract = True



from django.db import models
from edc_crf.crf_model_mixin import CrfModelMixin
from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
from edc_model import models as edc_models
from edc_visit_tracking.model_mixins import SubjectVisitMissedModelMixin

from meta_lists.models import SubjectVisitMissedReasons
from meta_subject.constants import MISSED_VISIT_ACTION


class SubjectVisitMissed(
    SubjectVisitMissedModelMixin,
    CrfWithActionModelMixin,
    edc_models.BaseUuidModel,
):

    action_name = MISSED_VISIT_ACTION

    tracking_identifier_prefix = "MV"

    action_identifier = models.CharField(max_length=50, unique=True, null=True)

    tracking_identifier = models.CharField(max_length=30, unique=True, null=True)

    missed_reasons = models.ManyToManyField(
        SubjectVisitMissedReasons, blank=True, related_name="meta_missed_reasons"
    )

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Missed Visit Report"
        verbose_name_plural = "Missed Visit Report"



screening_codenames = [
    "meta_screening.add_screeningpartone",
    "meta_screening.add_screeningpartthree",
    "meta_screening.add_screeningparttwo",
    "meta_screening.add_subjectrefusal",
    "meta_screening.change_screeningpartone",
    "meta_screening.change_screeningpartthree",
    "meta_screening.change_screeningparttwo",
    "meta_screening.change_subjectrefusal",
    "meta_screening.delete_screeningpartone",
    "meta_screening.delete_screeningpartthree",
    "meta_screening.delete_screeningparttwo",
    "meta_screening.delete_subjectrefusal",
    "meta_screening.view_historicalscreeningpartone",
    "meta_screening.view_historicalscreeningpartthree",
    "meta_screening.view_historicalscreeningparttwo",
    "meta_screening.view_historicalsubjectscreening",
    "meta_screening.view_historicalsubjectrefusal",
    "meta_screening.view_screeningpartone",
    "meta_screening.view_screeningpartthree",
    "meta_screening.view_screeningparttwo",
    "meta_screening.view_subjectscreening",
    "meta_screening.view_subjectrefusal",
]
screening_codenames.sort()



from edc_blood_results import BLOOD_RESULTS_HBA1C_ACTION
from edc_blood_results.model_mixins import BloodResultsModelMixin, Hba1cModelMixin
from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
from edc_lab.model_mixins import CrfWithRequisitionModelMixin
from edc_model import models as edc_models


class BloodResultsHba1c(
    CrfWithActionModelMixin,
    Hba1cModelMixin,
    CrfWithRequisitionModelMixin,
    BloodResultsModelMixin,
    edc_models.BaseUuidModel,
):
    action_name = BLOOD_RESULTS_HBA1C_ACTION
    tracking_identifier_prefix = "HA"

    class Meta(CrfWithActionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Blood Result: HbA1c"
        verbose_name_plural = "Blood Results: HbA1c"



from django.contrib import admin
from edc_adverse_event.modeladmin_mixins import DeathReportTmgModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import meta_ae_admin
from ..forms import DeathReportTmgSecondForm
from ..models import DeathReportTmgSecond


@admin.register(DeathReportTmgSecond, site=meta_ae_admin)
class DeathReportTmgSecondAdmin(DeathReportTmgModelAdminMixin, SimpleHistoryAdmin):

    form = DeathReportTmgSecondForm



from django import forms
from edc_action_item.forms import ActionItemFormMixin
from edc_blood_results.form_validator_mixins import BloodResultsFormValidatorMixin
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_form_validators import FormValidator
from edc_lab_panel.panels import lipids_panel

from ...models import BloodResultsLipid


class BloodResultsLipidFormValidator(BloodResultsFormValidatorMixin, FormValidator):
    panel = lipids_panel


class BloodResultsLipidForm(ActionItemFormMixin, CrfModelFormMixin, forms.ModelForm):

    form_validator_cls = BloodResultsLipidFormValidator

    class Meta:
        model = BloodResultsLipid
        fields = "__all__"



from django import forms
from django.test import TestCase
from edc_lab.models import Panel
from edc_reportable import MILLIGRAMS_PER_DECILITER

from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin
from meta_subject.forms.blood_results.blood_results_rft_form import (
    BloodResultsRftFormValidator,
)
from meta_subject.models import BloodResultsRft, SubjectRequisition


class TestEgfr(MetaTestCaseMixin, TestCase):
    def setUp(self):
        super().setUp()
        self.subject_visit = self.get_subject_visit()
        panel = Panel.objects.get(name="chemistry_rft")
        requisition = SubjectRequisition.objects.create(
            subject_visit=self.subject_visit,
            panel=panel,
            requisition_datetime=self.subject_visit.report_datetime,
        )
        self.data = dict(subject_visit=self.subject_visit, requisition=requisition)

    def test_model(self):
        self.data.update(
            creatinine_value=1.1, creatinine_units=MILLIGRAMS_PER_DECILITER
        )
        obj = BloodResultsRft.objects.create(**self.data)
        self.assertIsNotNone(obj.egfr_value)
        self.assertIsNotNone(obj.egfr_units)

    def test_ok(self):
        data = dict(subject_visit=self.subject_visit)
        form = BloodResultsRftFormValidator(cleaned_data=data)
        try:
            form.validate()
        except forms.ValidationError:
            pass
        self.assertEqual({}, form._errors)



# Generated by Django 3.2.6 on 2021-08-23 20:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0026_auto_20210712_0433"),
    ]

    operations = []



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_form_validators import FormValidator

from ..models import StudyMedication


class StudyMedicationFormValidator(FormValidator):
    def clean(self):
        pass


class StudyMedicationForm(CrfModelFormMixin, forms.ModelForm):

    form_validator_cls = StudyMedicationFormValidator

    class Meta:
        model = StudyMedication
        fields = "__all__"



from django import forms
from edc_constants.constants import NEG, NO, POS, YES
from edc_form_validators import FormValidator
from edc_glucose.form_validators import (
    FastingFormValidatorMixin,
    FbgOgttFormValidatorMixin,
    GlucoseFormValidatorMixin,
)
from edc_glucose.utils import validate_glucose_as_millimoles_per_liter
from edc_reportable import BmiFormValidatorMixin, EgfrFormValidatorMixin
from edc_vitals.form_validators import (
    BloodPressureFormValidatorMixin,
    WeightHeightBmiFormValidatorMixin,
)

from meta_screening.forms import get_part_three_vitals_fields
from meta_screening.models import SubjectScreening


class ScreeningPartThreeFormValidatorError(Exception):
    pass


class ScreeningPartThreeFormValidator(
    GlucoseFormValidatorMixin,
    FastingFormValidatorMixin,
    FbgOgttFormValidatorMixin,
    BmiFormValidatorMixin,
    EgfrFormValidatorMixin,
    BloodPressureFormValidatorMixin,
    WeightHeightBmiFormValidatorMixin,
    FormValidator,
):
    def clean(self):
        self.validate_report_datetimes()
        self.require_all_vitals_fields()
        self.validate_weight_height_with_bmi(
            weight_kg=self.cleaned_data.get("weight"),
            height_cm=self.cleaned_data.get("height"),
            lower_bmi_value=SubjectScreening.lower_bmi_value,
            upper_bmi_value=SubjectScreening.upper_bmi_value,
        )
        self.raise_on_avg_blood_pressure_suggests_severe_htn(**self.cleaned_data)
        self.validate_pregnancy()
        self.validate_fasting_required_fields()
        self.validate_fbg_required_fields("fbg", "part_three_report_datetime")
        validate_glucose_as_millimoles_per_liter("fbg", self.cleaned_data)
        self.validate_fbg_before_ogtt()
        self.validate_ogtt_time_interval()
        self.validate_ogtt_required_fields()
        self.validate_ogtt_dates()
        validate_glucose_as_millimoles_per_liter("ogtt", self.cleaned_data)
        self.applicable_if(
            YES, field="repeat_glucose_performed", field_applicable="repeat_fasting"
        )
        self.validate_fasting_required_fields(fasting_prefix="repeat_fasting")
        self.validate_repeat_fbg()
        self.validate_repeat_ogtt()
        self.validate_creatinine_required_fields()
        self.required_if(YES, field="hba1c_performed", field_required="hba1c_value")
        self.validate_egfr()
        self.validate_suitability_for_study()

    def validate_repeat_fbg(self):
        """Validate like first FBG and ...

        Ensure repeat FBG at least three days after first FBG
        """
        self.applicable_if(
            YES,
            field="repeat_glucose_opinion",
            field_applicable="repeat_glucose_performed",
        )
        for fld in [
            "fbg2_datetime",
            "fbg2_value",
            "fbg2_units",
        ]:
            self.required_if(YES, field="repeat_glucose_performed", field_required=fld)

    def validate_repeat_ogtt(self):
        """Validate like first OGTT and ...

        Ensure repeat OGTT at least three days after first OGTT
        """
        self.applicable_if(
            YES,
            field="repeat_glucose_opinion",
            field_applicable="repeat_glucose_performed",
        )
        for fld in [
            "ogtt2_base_datetime",
            "ogtt2_datetime",
            "ogtt2_value",
            "ogtt2_units",
        ]:
            self.required_if(YES, field="repeat_glucose_performed", field_required=fld)
        if self.cleaned_data.get("repeat_glucose_performed") == YES:
            for ogtt_dte, ogtt2_dte in [
                ("ogtt_base_datetime", "ogtt2_base_datetime"),
                ("ogtt_datetime", "ogtt2_datetime"),
            ]:
                if self.cleaned_data.get(ogtt_dte) and self.cleaned_data.get(ogtt2_dte):
                    tdelta = (
                        self.cleaned_data.get(ogtt2_dte).date()
                        - self.cleaned_data.get(ogtt_dte).date()
                    )
                    if tdelta.days < 3:
                        raise forms.ValidationError(
                            {
                                ogtt2_dte: "Invalid. Must be at least 3 days after first OGTT"
                            }
                        )
            self.validate_ogtt_time_interval(ogtt_prefix="ogtt2")
            self.validate_ogtt_required_fields(ogtt_prefix="ogtt2")
            self.validate_ogtt_dates(ogtt_prefix="ogtt2")
            validate_glucose_as_millimoles_per_liter("ogtt2", self.cleaned_data)

    def validate_report_datetimes(self):
        pass

    def validate_suitability_for_study(self):
        self.required_if(
            YES, field="unsuitable_for_study", field_required="reasons_unsuitable"
        )

        self.applicable_if(
            YES, field="unsuitable_for_study", field_applicable="unsuitable_agreed"
        )

        if self.cleaned_data.get("unsuitable_agreed") == NO:
            raise forms.ValidationError(
                {
                    "unsuitable_agreed": "The study coordinator MUST agree "
                    "with your assessment. Please discuss before continuing."
                }
            )

    def validate_creatinine_required_fields(self):
        self.required_if(
            YES, field="creatinine_performed", field_required="creatinine_value"
        )
        self.required_if_true(
            self.cleaned_data.get("creatinine_value"), field_required="creatinine_units"
        )

    def validate_pregnancy(self):
        self.applicable_if(
            YES,
            NO,
            field="pregnant",
            field_applicable="urine_bhcg_performed",
            is_instance_field=True,
            msg="See response in part one.",
        )
        self.applicable_if(
            YES, field="urine_bhcg_performed", field_applicable="urine_bhcg_value"
        )
        self.required_if(
            YES, field="urine_bhcg_performed", field_required="urine_bhcg_date"
        )

        if (
            self.instance.pregnant == YES
            and self.cleaned_data.get("urine_bhcg_value") == NEG
        ):
            raise forms.ValidationError(
                {"urine_bhcg_value": "Invalid, part one says subject is pregnant"}
            )
        elif (
            self.instance.pregnant == NO
            and self.cleaned_data.get("urine_bhcg_value") == POS
        ):
            raise forms.ValidationError(
                {"urine_bhcg_value": "Invalid, part one says subject is not pregnant"}
            )

    def require_all_vitals_fields(self):
        require_all = False
        fields = get_part_three_vitals_fields()
        fields.remove("waist_circumference")
        for field in fields:
            if self.cleaned_data.get(field):
                require_all = True
                break
        if require_all:
            for field in fields:
                if not self.cleaned_data.get(field):
                    raise forms.ValidationError({field: "This field is required"})



# Generated by Django 3.2.6 on 2021-09-09 23:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_action_item", "0028_auto_20210203_0706"),
        ("edc_protocol_violation", "0001_initial"),
        ("meta_prn", "0007_auto_20210721_0335"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="site",
        ),
        migrations.DeleteModel(
            name="UnblindingRequestorUser",
        ),
        migrations.DeleteModel(
            name="UnblindingReviewerUser",
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingRequest",
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingReview",
        ),
        migrations.DeleteModel(
            name="UnblindingRequest",
        ),
        migrations.DeleteModel(
            name="UnblindingReview",
        ),
    ]



# Generated by Django 3.2.4 on 2021-07-28 15:09

import _socket
from django.conf import settings
import django.contrib.sites.managers
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0012_auto_20210728_1809"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("meta_subject", "0067_auto_20210726_0340"),
    ]

    operations = [
        migrations.CreateModel(
            name="Mnsi",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.models.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "numb_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your legs and/or feet numb?",
                    ),
                ),
                (
                    "burning_pain_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you ever have any burning pain in your legs and/or feet?",
                    ),
                ),
                (
                    "feet_sensitive_touch",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your feet too sensitive to touch?",
                    ),
                ),
                (
                    "muscle_cramps_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you get muscle cramps in your legs and/or feet?",
                    ),
                ),
                (
                    "prickling_feelings_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you ever have any prickling feelings in your legs or feet?",
                    ),
                ),
                (
                    "covers_touch_skin_painful",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Does it hurt when the bed covers touch your skin?",
                    ),
                ),
                (
                    "differentiate_hot_cold_water",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
                    ),
                ),
                (
                    "open_sore_foot_history",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Have you ever had an open sore on your foot?",
                    ),
                ),
                (
                    "diabetic_neuropathy",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
                    ),
                ),
                (
                    "feel_weak",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you feel weak all over most of the time?",
                    ),
                ),
                (
                    "symptoms_worse_night",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your symptoms worse at night?",
                    ),
                ),
                (
                    "legs_hurt_when_walk",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do your legs hurt when you walk?",
                    ),
                ),
                (
                    "sense_feet_when_walk",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are you able to sense your feet when you walk?",
                    ),
                ),
                (
                    "skin_cracks_open_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the skin on your feet so dry that it cracks open?",
                    ),
                ),
                (
                    "amputation",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Have you ever had an amputation?",
                    ),
                ),
                (
                    "examined_right_foot",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was RIGHT foot examined?",
                    ),
                ),
                (
                    "normal_appearance_right_foot",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does RIGHT foot appear normal?",
                    ),
                ),
                (
                    "abnormal_obs_right_foot_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other abnormality observed on RIGHT foot, please specify ...",
                    ),
                ),
                (
                    "ulceration_right_foot",
                    models.CharField(
                        choices=[
                            ("absent", "Absent"),
                            ("present", "Present"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Ulceration, RIGHT foot?",
                    ),
                ),
                (
                    "ankle_reflexes_right_foot",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("present_with_reinforcement", "Present/Reinforcement"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=35,
                        verbose_name="Ankle reflexes, RIGHT foot?",
                    ),
                ),
                (
                    "vibration_perception_right_toe",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("decreased", "Decreased"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Vibration perception at great toe, RIGHT foot?",
                    ),
                ),
                (
                    "monofilament_right_foot",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("reduced", "Reduced"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Monofilament, RIGHT foot?",
                    ),
                ),
                (
                    "examined_left_foot",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was LEFT foot examined?",
                    ),
                ),
                (
                    "normal_appearance_left_foot",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does LEFT foot appear normal?",
                    ),
                ),
                (
                    "abnormal_obs_left_foot_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other abnormality observed on LEFT foot, please specify ...",
                    ),
                ),
                (
                    "ulceration_left_foot",
                    models.CharField(
                        choices=[
                            ("absent", "Absent"),
                            ("present", "Present"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Ulceration, LEFT foot?",
                    ),
                ),
                (
                    "ankle_reflexes_left_foot",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("present_with_reinforcement", "Present/Reinforcement"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=35,
                        verbose_name="Ankle reflexes, LEFT foot?",
                    ),
                ),
                (
                    "vibration_perception_left_toe",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("decreased", "Decreased"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Vibration perception at great toe, LEFT foot?",
                    ),
                ),
                (
                    "monofilament_left_foot",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("reduced", "Reduced"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Monofilament, LEFT foot?",
                    ),
                ),
                (
                    "calculated_patient_history_score",
                    models.IntegerField(
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(13),
                        ],
                    ),
                ),
                (
                    "calculated_physical_assessment_score",
                    models.DecimalField(
                        decimal_places=1,
                        max_digits=3,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10.0),
                        ],
                    ),
                ),
                (
                    "abnormal_obs_left_foot",
                    models.ManyToManyField(
                        blank=True,
                        related_name="abnormal_obs_left_foot",
                        to="meta_lists.AbnormalFootAppearanceObservations",
                        verbose_name="If NO, check all that apply to LEFT foot?",
                    ),
                ),
                (
                    "abnormal_obs_right_foot",
                    models.ManyToManyField(
                        blank=True,
                        related_name="abnormal_obs_right_foot",
                        to="meta_lists.AbnormalFootAppearanceObservations",
                        verbose_name="If NO, check all that apply to RIGHT foot?",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Michigan Neuropathy Screening Instrument (MNSI)",
                "verbose_name_plural": "Michigan Neuropathy Screening Instrument (MNSI)",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalMnsi",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.models.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "numb_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your legs and/or feet numb?",
                    ),
                ),
                (
                    "burning_pain_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you ever have any burning pain in your legs and/or feet?",
                    ),
                ),
                (
                    "feet_sensitive_touch",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your feet too sensitive to touch?",
                    ),
                ),
                (
                    "muscle_cramps_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you get muscle cramps in your legs and/or feet?",
                    ),
                ),
                (
                    "prickling_feelings_legs_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you ever have any prickling feelings in your legs or feet?",
                    ),
                ),
                (
                    "covers_touch_skin_painful",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Does it hurt when the bed covers touch your skin?",
                    ),
                ),
                (
                    "differentiate_hot_cold_water",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="When you get into the tub or shower, are you able to tell the hot water from the cold water?",
                    ),
                ),
                (
                    "open_sore_foot_history",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Have you ever had an open sore on your foot?",
                    ),
                ),
                (
                    "diabetic_neuropathy",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Has your doctor ever told you that you have diabetic neuropathy?",
                    ),
                ),
                (
                    "feel_weak",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you feel weak all over most of the time?",
                    ),
                ),
                (
                    "symptoms_worse_night",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are your symptoms worse at night?",
                    ),
                ),
                (
                    "legs_hurt_when_walk",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do your legs hurt when you walk?",
                    ),
                ),
                (
                    "sense_feet_when_walk",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Are you able to sense your feet when you walk?",
                    ),
                ),
                (
                    "skin_cracks_open_feet",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the skin on your feet so dry that it cracks open?",
                    ),
                ),
                (
                    "amputation",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Have you ever had an amputation?",
                    ),
                ),
                (
                    "examined_right_foot",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was RIGHT foot examined?",
                    ),
                ),
                (
                    "normal_appearance_right_foot",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does RIGHT foot appear normal?",
                    ),
                ),
                (
                    "abnormal_obs_right_foot_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other abnormality observed on RIGHT foot, please specify ...",
                    ),
                ),
                (
                    "ulceration_right_foot",
                    models.CharField(
                        choices=[
                            ("absent", "Absent"),
                            ("present", "Present"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Ulceration, RIGHT foot?",
                    ),
                ),
                (
                    "ankle_reflexes_right_foot",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("present_with_reinforcement", "Present/Reinforcement"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=35,
                        verbose_name="Ankle reflexes, RIGHT foot?",
                    ),
                ),
                (
                    "vibration_perception_right_toe",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("decreased", "Decreased"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Vibration perception at great toe, RIGHT foot?",
                    ),
                ),
                (
                    "monofilament_right_foot",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("reduced", "Reduced"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Monofilament, RIGHT foot?",
                    ),
                ),
                (
                    "examined_left_foot",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was LEFT foot examined?",
                    ),
                ),
                (
                    "normal_appearance_left_foot",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Does LEFT foot appear normal?",
                    ),
                ),
                (
                    "abnormal_obs_left_foot_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other abnormality observed on LEFT foot, please specify ...",
                    ),
                ),
                (
                    "ulceration_left_foot",
                    models.CharField(
                        choices=[
                            ("absent", "Absent"),
                            ("present", "Present"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Ulceration, LEFT foot?",
                    ),
                ),
                (
                    "ankle_reflexes_left_foot",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("present_with_reinforcement", "Present/Reinforcement"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=35,
                        verbose_name="Ankle reflexes, LEFT foot?",
                    ),
                ),
                (
                    "vibration_perception_left_toe",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("decreased", "Decreased"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Vibration perception at great toe, LEFT foot?",
                    ),
                ),
                (
                    "monofilament_left_foot",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("reduced", "Reduced"),
                            ("absent", "Absent"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Monofilament, LEFT foot?",
                    ),
                ),
                (
                    "calculated_patient_history_score",
                    models.IntegerField(
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(13),
                        ],
                    ),
                ),
                (
                    "calculated_physical_assessment_score",
                    models.DecimalField(
                        decimal_places=1,
                        max_digits=3,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10.0),
                        ],
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Michigan Neuropathy Screening Instrument (MNSI)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.AddIndex(
            model_name="mnsi",
            index=models.Index(
                fields=["subject_visit", "site", "id"],
                name="meta_subjec_subject_0deea5_idx",
            ),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-21 02:34

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_subject", "0002_auto_20191021_0353")]

    operations = [
        migrations.AlterField(
            model_name="followupvitals",
            name="oxygen_saturation",
            field=models.IntegerField(
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Oxygen saturation:",
            ),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="respiratory_rate",
            field=models.IntegerField(
                help_text="breaths/min",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(6),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Respiratory rate:",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="oxygen_saturation",
            field=models.IntegerField(
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Oxygen saturation:",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="respiratory_rate",
            field=models.IntegerField(
                help_text="breaths/min",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(6),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Respiratory rate:",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="oxygen_saturation",
            field=models.IntegerField(
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Oxygen saturation:",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="respiratory_rate",
            field=models.IntegerField(
                help_text="breaths/min",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(6),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Respiratory rate:",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="oxygen_saturation",
            field=models.IntegerField(
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Oxygen saturation:",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="respiratory_rate",
            field=models.IntegerField(
                help_text="breaths/min",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(6),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Respiratory rate:",
            ),
        ),
    ]



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_subject_admin
from ..forms import ComplicationsGlycemiaForm
from ..models import ComplicationsGlycemia
from .modeladmin import CrfModelAdmin


@admin.register(ComplicationsGlycemia, site=meta_subject_admin)
class ComplicationsGlycemiaAdmin(CrfModelAdmin):

    form = ComplicationsGlycemiaForm

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "subject_visit",
                    "report_datetime",
                )
            },
        ),
        (
            "Eye examination",
            {
                "fields": (
                    "cataracts",
                    "fundoscopy",
                )
            },
        ),
        (
            "Foot examination",
            {
                "fields": (
                    "foot_skin_condition",
                    "foot_fungal_infection",
                    "foot_sores",
                    "foot_callouses",
                )
            },
        ),
        (
            "Peripheral pulses and reflexes",
            {
                "fields": (
                    "dp_pulse",
                    "pt_pulse",
                    "at_reflex",
                )
            },
        ),
        (
            "Neuropathy Disability Score (NDS)",
            {
                "fields": (
                    "nds_vpt_right",
                    "nds_vpt_left",
                    "nds_tp_right",
                    "nds_tp_left",
                    "nds_pp_right",
                    "nds_pp_left",
                    "nds_achilles_reflex_right",
                    "nds_achilles_reflex_left",
                )
            },
        ),
        (
            "10-g monofilament test",
            {
                "fields": (
                    "first_metatarsal_right",
                    "first_metatarsal_left",
                    "third_metatarsal_right",
                    "third_metatarsal_left",
                    "fifth_metatarsal_right",
                    "fifth_metatarsal_left",
                    "plantar_surface_right",
                    "plantar_surface_left",
                )
            },
        ),
        (
            "Diabetic Neuropathy Symptom Score",
            {
                "fields": (
                    "dns_walking",
                    "dns_burning",
                    "dns_tingling",
                    "dns_numbness",
                )
            },
        ),
        audit_fieldset_tuple,
    )

    radio_fields = {
        "at_reflex": admin.VERTICAL,
        "cataracts": admin.VERTICAL,
        "dns_burning": admin.VERTICAL,
        "dns_numbness": admin.VERTICAL,
        "dns_tingling": admin.VERTICAL,
        "dns_walking": admin.VERTICAL,
        "dp_pulse": admin.VERTICAL,
        "fifth_metatarsal_right": admin.VERTICAL,
        "fifth_metatarsal_left": admin.VERTICAL,
        "first_metatarsal_right": admin.VERTICAL,
        "first_metatarsal_left": admin.VERTICAL,
        "foot_callouses": admin.VERTICAL,
        "foot_fungal_infection": admin.VERTICAL,
        "foot_skin_condition": admin.VERTICAL,
        "foot_sores": admin.VERTICAL,
        "fundoscopy": admin.VERTICAL,
        "nds_achilles_reflex_left": admin.VERTICAL,
        "nds_achilles_reflex_right": admin.VERTICAL,
        "nds_pp_left": admin.VERTICAL,
        "nds_pp_right": admin.VERTICAL,
        "nds_tp_left": admin.VERTICAL,
        "nds_tp_right": admin.VERTICAL,
        "nds_vpt_left": admin.VERTICAL,
        "nds_vpt_right": admin.VERTICAL,
        "plantar_surface_left": admin.VERTICAL,
        "plantar_surface_right": admin.VERTICAL,
        "pt_pulse": admin.VERTICAL,
        "third_metatarsal_right": admin.VERTICAL,
        "third_metatarsal_left": admin.VERTICAL,
    }



# Generated by Django 3.0.4 on 2020-04-17 00:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0018_coronakap_historicalcoronakap"),
    ]

    operations = [
        migrations.RenameField(
            model_name="coronakap",
            old_name="profession",
            new_name="employment",
        ),
        migrations.RenameField(
            model_name="coronakap",
            old_name="other_health_insurance",
            new_name="employment_other",
        ),
        migrations.RenameField(
            model_name="coronakap",
            old_name="other_profession",
            new_name="health_insurance_other",
        ),
        migrations.RenameField(
            model_name="coronakap",
            old_name="other_symptoms",
            new_name="symptoms_other",
        ),
        migrations.RenameField(
            model_name="historicalcoronakap",
            old_name="profession",
            new_name="employment",
        ),
        migrations.RenameField(
            model_name="historicalcoronakap",
            old_name="other_health_insurance",
            new_name="employment_other",
        ),
        migrations.RenameField(
            model_name="historicalcoronakap",
            old_name="other_profession",
            new_name="health_insurance_other",
        ),
        migrations.RenameField(
            model_name="historicalcoronakap",
            old_name="other_symptoms",
            new_name="symptoms_other",
        ),
    ]



from django.contrib import admin
from edc_blood_results.admin import BloodResultsModelAdminMixin
from edc_blood_results.fieldsets import BloodResultFieldset

from ...admin_site import meta_subject_admin
from ...forms import BloodResultsFbcForm
from ...models import BloodResultsFbc
from ..modeladmin import CrfModelAdmin


@admin.register(BloodResultsFbc, site=meta_subject_admin)
class BloodResultsFbcAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
    form = BloodResultsFbcForm
    fieldsets = BloodResultFieldset(
        BloodResultsFbc.lab_panel, model_cls=BloodResultsFbc
    ).fieldsets



from edc_constants.constants import NO, NOT_APPLICABLE, YES

BMI_FBG_OGTT_INCOMPLETE = "BMI/FBG/OGTT incomplete"
BMI_IFT_OGTT = "BMI/FBG/OGTT"
EGFR_NOT_CALCULATED = "eGFR not calculated"
EGFR_LT_45 = "eGFR<45"
FBG_OGTT_INCOMPLETE = "FBG/OGTT incomplete"
IFT_OGTT = "FBG/OGTT"
PART_ONE = "p1"
PART_TWO = "p2"
PART_THREE = "p3"

PREG_YES_NO_NA = (
    (YES, "Yes"),
    (NO, "No"),
    (NOT_APPLICABLE, "Not Applicable: e.g. mentruating, post menopausal, not female"),
)

CONVERSION_FACTOR = 18.018018
SEVERE_HTN = "Severe HTN"



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_subject_admin
from ..models import Complications
from .modeladmin import CrfModelAdmin


@admin.register(Complications, site=meta_subject_admin)
class ComplicationsAdmin(CrfModelAdmin):

    fieldsets = (
        ("Eye Examination", {"fields": ("cataracts", "fundoscopy")}),
        (
            "Foot Exam",
            {
                "fields": (
                    "achilles_tendon_reflex",
                    "foot_pin_prick",
                    "foot_light_touch",
                    "temperature_perception",
                )
            },
        ),
        (
            "Peripheral pulses",
            {"fields": ("dorsalis_pedis_pulse", "posterior_tibial_pulse")},
        ),
        audit_fieldset_tuple,
    )



from django.db import models
from edc_action_item.managers import (
    ActionIdentifierManager,
    ActionIdentifierSiteManager,
)
from edc_action_item.models import ActionModelMixin
from edc_model.models import date_not_future


class BaseStudyTerminationConclusion(ActionModelMixin, models.Model):
    last_study_fu_date = models.DateField(
        verbose_name="Date of last research follow up (if different):",
        validators=[date_not_future],
        blank=True,
        null=True,
    )

    death_date = models.DateField(
        verbose_name="Date of Death",
        validators=[date_not_future],
        blank=True,
        null=True,
    )

    consent_withdrawal_reason = models.CharField(
        verbose_name="Reason for withdrawing consent",
        max_length=75,
        blank=True,
        null=True,
    )

    on_site = ActionIdentifierSiteManager()

    objects = ActionIdentifierManager()

    def natural_key(self):
        return tuple(
            self.action_identifier,
        )

    class Meta:
        abstract = True



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_subject_admin
from ..forms import ConcomitantMedicationForm
from ..models import ConcomitantMedication
from .modeladmin import CrfModelAdmin


@admin.register(ConcomitantMedication, site=meta_subject_admin)
class ConcomitantMedicationAdmin(CrfModelAdmin):

    form = ConcomitantMedicationForm

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "subject_visit",
                    "report_datetime",
                )
            },
        ),
        audit_fieldset_tuple,
    )
